Module shared

Module shared 

everything in common between the gix and ein binaries.

Modules

prettypretty-cli

Structs

AsBString
AsHashKind
AsOutputFormat
AsPartialRefName
AsPathSpec
AsRange
AsTime
CheckPathSpec
ParseRenameFraction

Constants

DEFAULT_FRAME_RATEprodash-render-line or prodash-render-tui
STANDARD_RANGE

Functions

init_env_logger
If verbose is true, the env logger will be forcibly set to ‘info’ logging level. Otherwise env logging facilities will just be initialized.
progress_treeprodash-render-line
setup_line_renderer_rangeprodash-render-line

Type Aliases

ProgressRange