everything in common between the gix and ein binaries.
Modules
- pretty
pretty-cli
Structs
Constants
- DEFAULT_FRAME_RATE
prodash-render-lineorprodash-render-tui
Functions
- If verbose is true, the env logger will be forcibly set to ‘info’ logging level. Otherwise env logging facilities will just be initialized.
- progress_tree
prodash-render-line - setup_line_renderer_range
prodash-render-line